enum Message {
GetEncoders {
validate: bool,
tx: Sender<Result<Vec<Encoder>>>,
},
Encode {
builder: Box<Builder>,
tx: Sender<Result<Receiver<Result<Event, Error>>>>,
},
Close {
tx: Sender<()>,
},
}Expand description
A message for the encoder task
Variants
GetEncoders
Get encoders available to the application
Fields
Encode
Request an encode
Fields
Close
Request a shutdown.
the task will drain the channel until it is empty after recieving this. the task will still accept new messages until it processes this one.